@@ -14,9 +14,10 @@ sv_to_arg (SV * sv,
 	GITypeTag tag = g_type_info_get_tag (type_info);
 
 	if (!gperl_sv_is_defined (sv))
-		/* Interfaces and void types need to be able to handle undef
-		 * separately. */
+		/* Interfaces, booleans and void types need to be able to
+		 * handle undef separately.*/
 		if (!may_be_null && tag != GI_TYPE_TAG_INTERFACE
+		                 && tag != GI_TYPE_TAG_BOOLEAN
 		                 && tag != GI_TYPE_TAG_VOID)
 		{
 			if (arg_info) {
@@ -214,7 +215,8 @@ arg_to_sv (GIArgument * arg,
 		SV *sv;
 		gchar buffer[6];
 		gint length = g_unichar_to_utf8 (arg->v_uint32, buffer);
-		sv = newSVpv (buffer, length);
+		g_assert (length >= 0);
+		sv = newSVpv (buffer, (STRLEN) length);
 		SvUTF8_on (sv);
 		return sv;
 	    }
